{ config, lib, ... }:

{
  imports = [
    ./nginx.nix
  ];

  age.secrets = {
    env = {
      file = ../../secrets/vaultwarden/env.age;
    };
  };

  services.vaultwarden = {
    enable = true;
    dbBackend = "postgresql";

    environmentFile = config.age.secrets.env.path;
    config = {
      SENDMAIL_COMMAND = "${config.security.wrapperDir}/sendmail";
    };
  };
  users.users.vaultwarden.extraGroups = [ "nullmailer" ];

  systemd.services.vaultwarden = {
    path = [ "/run/wrappers" ];
    serviceConfig = {
      NoNewPrivileges = lib.mkForce false;
      PrivateUsers = lib.mkForce false;
      SystemCallFilter = lib.mkForce [ "@system-service" ];
      RestrictAddressFamilies = [
        "AF_LOCAL"
        "AF_NETLINK"
      ];
      ReadWritePaths = [ "/var/spool/nullmailer/" ];
    };
  };

  services.nginx.virtualHosts."vaultwarden.crans.org" = {
    locations."/" = {
      proxyPass = "http://localhost:8222";
      proxyWebsockets = true;
    };
  };
}
